# SUPU

Slightly Useful Python Utilities – a grab bag of small functions

These are really more like gists, but in a place where I can test them; if you want to
use them, it might just be easier to copy them into your own code than to add `supu` as
a dependency.
